@@ -13,8 +13,8 @@ import (
 	"github.com/openshift/cluster-version-operator/lib/resourcemerge"
 )
 
-// ApplyNamespace merges objectmeta, does not worry about anything else
-func ApplyNamespace(ctx context.Context, client coreclientv1.NamespacesGetter, required *corev1.Namespace) (*corev1.Namespace, bool, error) {
+// ApplyNamespacev1 merges objectmeta, does not worry about anything else
+func ApplyNamespacev1(ctx context.Context, client coreclientv1.NamespacesGetter, required *corev1.Namespace) (*corev1.Namespace, bool, error) {
 	existing, err := client.Namespaces().Get(ctx, required.Name, metav1.GetOptions{})
 	if apierrors.IsNotFound(err) {
 		actual, err := client.Namespaces().Create(ctx, required, metav1.CreateOptions{})
@@ -38,10 +38,10 @@ func ApplyNamespace(ctx context.Context, client coreclientv1.NamespacesGetter, r
 	return actual, true, err
 }
 
-// ApplyService merges objectmeta and requires
+// ApplyServicev1 merges objectmeta and requires
 // TODO, since this cannot determine whether changes are due to legitimate actors (api server) or illegitimate ones (users), we cannot update
 // TODO I've special cased the selector for now
-func ApplyService(ctx context.Context, client coreclientv1.ServicesGetter, required *corev1.Service) (*corev1.Service, bool, error) {
+func ApplyServicev1(ctx context.Context, client coreclientv1.ServicesGetter, required *corev1.Service) (*corev1.Service, bool, error) {
 	existing, err := client.Services(required.Namespace).Get(ctx, required.Name, metav1.GetOptions{})
 	if apierrors.IsNotFound(err) {
 		actual, err := client.Services(required.Namespace).Create(ctx, required, metav1.CreateOptions{})
@@ -71,8 +71,8 @@ func ApplyService(ctx context.Context, client coreclientv1.ServicesGetter, requi
 	return actual, true, err
 }
 
-// ApplyServiceAccount applies the required serviceaccount to the cluster.
-func ApplyServiceAccount(ctx context.Context, client coreclientv1.ServiceAccountsGetter, required *corev1.ServiceAccount) (*corev1.ServiceAccount, bool, error) {
+// ApplyServiceAccountv1 applies the required serviceaccount to the cluster.
+func ApplyServiceAccountv1(ctx context.Context, client coreclientv1.ServiceAccountsGetter, required *corev1.ServiceAccount) (*corev1.ServiceAccount, bool, error) {
 	existing, err := client.ServiceAccounts(required.Namespace).Get(ctx, required.Name, metav1.GetOptions{})
 	if apierrors.IsNotFound(err) {
 		actual, err := client.ServiceAccounts(required.Namespace).Create(ctx, required, metav1.CreateOptions{})
@@ -87,7 +87,7 @@ func ApplyServiceAccount(ctx context.Context, client coreclientv1.ServiceAccount
 	}
 
 	modified := pointer.BoolPtr(false)
-	resourcemerge.EnsureObjectMeta(modified, &existing.ObjectMeta, required.ObjectMeta)
+	resourcemerge.EnsureServiceAccount(modified, existing, *required)
 	if !*modified {
 		return existing, false, nil
 	}
@@ -96,8 +96,8 @@ func ApplyServiceAccount(ctx context.Context, client coreclientv1.ServiceAccount
 	return actual, true, err
 }
 
-// ApplyConfigMap applies the required serviceaccount to the cluster.
-func ApplyConfigMap(ctx context.Context, client coreclientv1.ConfigMapsGetter, required *corev1.ConfigMap) (*corev1.ConfigMap, bool, error) {
+// ApplyConfigMapv1 applies the required serviceaccount to the cluster.
+func ApplyConfigMapv1(ctx context.Context, client coreclientv1.ConfigMapsGetter, required *corev1.ConfigMap) (*corev1.ConfigMap, bool, error) {
 	existing, err := client.ConfigMaps(required.Namespace).Get(ctx, required.Name, metav1.GetOptions{})
 	if apierrors.IsNotFound(err) {
 		actual, err := client.ConfigMaps(required.Namespace).Create(ctx, required, metav1.CreateOptions{})
